---
meta:
    title: Data Subsetter
    description:
layout: component
---

```html:preview
<terra-data-subsetter collection-entry-id="OMAERO_003"></terra-data-subsetter>
```

## Examples

### Subsetter in dialog

```html:preview
<div style="height: 200px;">
    <terra-dialog id="my-dialog">
        <terra-data-subsetter collection-entry-id="OMAERO_003"></terra-data-subsetter>
    </terra-dialog>

    <terra-button for-dialog="my-dialog">
        Open Subsetter
    </button>
</div>
```

[component-metadata:terra-data-subsetter]
